==> alibabacloud_esa20240910-2.4.1.tar.gz: alibabacloud_esa20240910-2.4.1/ChangeLog.md <==
2024-10-28 Version: 2.4.0
- Support API CreateEdgeContainerApp.
- Support API CreateEdgeContainerAppRecord.
- Support API CreateEdgeContainerAppVersion.
- Support API DeleteEdgeContainerApp.
- Support API DeleteEdgeContainerAppRecord.
- Support API DeleteEdgeContainerAppVersion.
- Support API GetEdgeContainerApp.
- Support API GetEdgeContainerAppStatus.
- Support API GetEdgeContainerAppVersion.
- Support API GetEdgeContainerDeployRegions.
- Support API GetEdgeContainerLogs.
- Support API GetEdgeContainerStagingDeployStatus.
- Support API GetEdgeContainerTerminal.
- Support API ListEdgeContainerAppVersions.
- Support API PublishEdgeContainerAppVersion.
- Support API RebuildEdgeContainerAppStagingEnv.
- Support API RollbackEdgeContainerAppVersion.


2024-10-18 Version: 2.3.1
- Update API CreateSiteDeliveryTask: update param DiscardRate.
- Update API CreateSiteDeliveryTask: update param SiteId.


2024-10-16 Version: 2.3.0
- Support API CommitRoutineStagingCode.
- Support API CreateRoutine.
- Support API CreateRoutineRelatedRecord.
- Support API CreateRoutineRelatedRoute.
- Support API DeleteRoutine.
- Support API DeleteRoutineCodeVersion.
- Support API DeleteRoutineRelatedRecord.
- Support API DeleteRoutineRelatedRoute.
- Support API GetErService.
- Support API GetRoutine.
- Support API GetRoutineStagingCodeUploadInfo.
- Support API GetRoutineStagingEnvIp.
- Support API GetRoutineUserInfo.
- Support API ListRoutineCanaryAreas.
- Support API ListRoutineOptionalSpecs.
- Support API PublishRoutineCodeVersion.


2024-10-12 Version: 2.2.0
- Support API ListClientCertificates.


2024-10-11 Version: 2.1.0
- Support API DeleteKv.
- Support API DeleteKvNamespace.
- Support API DescribeKvAccountStatus.
- Support API GetKv.
- Support API GetKvAccount.


2024-10-11 Version: 2.0.1
- Update API CreateRecord: update param HostPolicy.
- Update API UpdateRecord: update param HostPolicy.


2024-10-10 Version: 2.0.0
- Support API GetCacheReserveSpecification.
- Support API ListCacheReserveInstances.
- Support API ListEdgeContainerApps.
- Support API ListEdgeRoutinePlans.
- Support API ListInstanceQuotas.
- Support API ListInstanceQuotasWithUsage.
- Support API ListUserRatePlanInstances.
- Support API ListWafManagedRules.
- Delete API AddUserBusinessForm.
- Delete API AdvancePurgeObjectCache.
- Delete API PutKvAccount.
- Update API SetCertificate: update param SiteId.


2024-10-08 Version: 1.0.0
- Generated python 2024-09-10 for ESA.

==> alibabacloud_esa20240910-2.5.0.tar.gz: alibabacloud_esa20240910-2.5.0/ChangeLog.md <==
2024-11-20 Version: 2.4.5
- Update API DescribeDDoSAllEventList: update response param.


2024-11-19 Version: 2.4.4
- Update API ListRecords: update param Proxied.


2024-11-13 Version: 2.4.3
- Update API BatchCreateRecords: update param RecordList.
- Update API CreateScheduledPreloadExecutions: update param Executions.
- Update API GetEdgeContainerAppVersion: update response param.
- Update API ListEdgeContainerAppVersions: update response param.
- Update API ListUserRatePlanInstances: update response param.
- Update API ListWafManagedRules: add param ProtectionLevel.
- Update API ListWafManagedRules: update param QueryArgs.
- Update API ListWafTemplateRules: add param SiteId.


2024-11-08 Version: 2.4.2
- Generated python 2024-09-10 for ESA.

2024-11-06 Version: 2.4.1
- Generated python 2024-09-10 for ESA.

2024-10-28 Version: 2.4.0
- Support API CreateEdgeContainerApp.
- Support API CreateEdgeContainerAppRecord.
- Support API CreateEdgeContainerAppVersion.
- Support API DeleteEdgeContainerApp.
- Support API DeleteEdgeContainerAppRecord.
- Support API DeleteEdgeContainerAppVersion.
- Support API GetEdgeContainerApp.
- Support API GetEdgeContainerAppStatus.
- Support API GetEdgeContainerAppVersion.
- Support API GetEdgeContainerDeployRegions.
- Support API GetEdgeContainerLogs.
- Support API GetEdgeContainerStagingDeployStatus.
- Support API GetEdgeContainerTerminal.
- Support API ListEdgeContainerAppVersions.
- Support API PublishEdgeContainerAppVersion.
- Support API RebuildEdgeContainerAppStagingEnv.
- Support API RollbackEdgeContainerAppVersion.


2024-10-18 Version: 2.3.1
- Update API CreateSiteDeliveryTask: update param DiscardRate.
- Update API CreateSiteDeliveryTask: update param SiteId.


2024-10-16 Version: 2.3.0
- Support API CommitRoutineStagingCode.
- Support API CreateRoutine.
- Support API CreateRoutineRelatedRecord.
- Support API CreateRoutineRelatedRoute.
- Support API DeleteRoutine.
- Support API DeleteRoutineCodeVersion.
- Support API DeleteRoutineRelatedRecord.
- Support API DeleteRoutineRelatedRoute.
- Support API GetErService.
- Support API GetRoutine.
- Support API GetRoutineStagingCodeUploadInfo.
- Support API GetRoutineStagingEnvIp.
- Support API GetRoutineUserInfo.
- Support API ListRoutineCanaryAreas.
- Support API ListRoutineOptionalSpecs.
- Support API PublishRoutineCodeVersion.


2024-10-12 Version: 2.2.0
- Support API ListClientCertificates.


2024-10-11 Version: 2.1.0
- Support API DeleteKv.
- Support API DeleteKvNamespace.
- Support API DescribeKvAccountStatus.
- Support API GetKv.
- Support API GetKvAccount.


2024-10-11 Version: 2.0.1
- Update API CreateRecord: update param HostPolicy.
- Update API UpdateRecord: update param HostPolicy.


2024-10-10 Version: 2.0.0
- Support API GetCacheReserveSpecification.
- Support API ListCacheReserveInstances.
- Support API ListEdgeContainerApps.
- Support API ListEdgeRoutinePlans.
- Support API ListInstanceQuotas.
- Support API ListInstanceQuotasWithUsage.
- Support API ListUserRatePlanInstances.
- Support API ListWafManagedRules.
- Delete API AddUserBusinessForm.
- Delete API AdvancePurgeObjectCache.
- Delete API PutKvAccount.
- Update API SetCertificate: update param SiteId.


2024-10-08 Version: 1.0.0
- Generated python 2024-09-10 for ESA.
